@@ -1,6 +1,9 @@
 """Analyse micromagnetic data."""
-import pytest
 import pkg_resources
+import pytest
+
+from .abstract_drive import AbstractDrive
+from .combined_drive import CombinedDrive
 from .data import Data
 from .drive import Drive
 
@@ -19,5 +22,6 @@ def test():
     >>> # micromagneticdata.test()
 
     """
-    return pytest.main(['-v', '--pyargs',
-                        'micromagneticdata', '-l'])  # pragma: no cover
+    return pytest.main(
+        ["-v", "--pyargs", "micromagneticdata", "-l"]
+    )  # pragma: no cover
