@@ -1,16 +1,23 @@
-import os
 import glob
 import json
+import os
+
+import discretisedfield as df
 import ipywidgets
 import ubermagtable as ut
-import discretisedfield as df
+import ubermagutil as uu
 import ubermagutil.typesystem as ts
 
+import micromagneticdata as md
 
-@ts.typesystem(name=ts.Typed(expected_type=str),
-               number=ts.Scalar(expected_type=int, unsigned=True),
-               dirname=ts.Typed(expected_type=str))
-class Drive:
+
+@uu.inherit_docs
+@ts.typesystem(
+    name=ts.Typed(expected_type=str),
+    number=ts.Scalar(expected_type=int, unsigned=True),
+    dirname=ts.Typed(expected_type=str),
+)
+class Drive(md.AbstractDrive):
     """Drive class.
 
     This class provides utility for the analysis of individual drives.
@@ -52,16 +59,22 @@ class Drive:
     >>> drive = md.Drive(name='system_name', number=0, dirname=dirname)
 
     """
-    def __init__(self, name, number, dirname='./', x=None):
+
+    def __init__(self, name, number, dirname="./", x=None):
         self.name = name
         self.number = number
         self.dirname = dirname
-        self.path = os.path.join(dirname, name, f'drive-{number}')
+
+        self.path = os.path.join(dirname, name, f"drive-{number}")
+        if not os.path.exists(self.path):
+            msg = f"Directory {self.path=} does not exist."
+            raise IOError(msg)
+
         self.x = x
 
-        if not os.path.exists(self.path):
-            msg = f'Directory {self.path=} does not exist.'
-            raise IOError(msg)
+    @property
+    def _m0_path(self):
+        return os.path.join(self.path, "m0.omf")
 
     def __repr__(self):
         """Representation string.
@@ -86,63 +99,10 @@ class Drive:
         Drive(...)
 
         """
-        return (f'Drive(name=\'{self.name}\', number={self.number}, '
-                f'dirname=\'{self.dirname}\', x=\'{self.x}\')')
-
-    @property
-    def x(self):
-        """Independent variable name.
-
-        Parameters
-        ----------
-        value : str
-
-            Independent variable name.
-
-        Returns
-        -------
-        str
-
-            Representation string.
-
-        Raises
-        ------
-        ValueError
-
-            If the column name does not exist in table.
-
-        Examples
-        --------
-        1. Getting and setting independent variable name.
-
-        >>> import os
-        >>> import micromagneticdata as md
-        ...
-        >>> dirname = dirname=os.path.join(os.path.dirname(__file__),
-        ...                                'tests', 'test_sample')
-        >>> drive = md.Drive(name='system_name', number=6, dirname=dirname)
-        >>> drive.x
-        'B_hysteresis'
-        >>> drive.x = 'Bx_hysteresis'
-
-        """
-        return self._x
-
-    @x.setter
-    def x(self, value):
-        if value is None:
-            if self.info['driver'] == 'TimeDriver':
-                self._x = 't'
-            elif self.info['driver'] == 'MinDriver':
-                self._x = 'iteration'
-            elif self.info['driver'] == 'HysteresisDriver':
-                self._x = 'B_hysteresis'
-        else:
-            if value in self.table.data.columns:
-                self._x = value
-            else:
-                msg = f'Column {value=} does not exist in data.'
-                raise ValueError(msg)
+        return (
+            f"Drive(name='{self.name}', number={self.number}, "
+            f"dirname='{self.dirname}', x='{self.x}')"
+        )
 
     @property
     def info(self):
@@ -170,25 +130,22 @@ class Drive:
         {...}
 
         """
-        with open(os.path.join(self.path, 'info.json')) as f:
+        with open(os.path.join(self.path, "info.json")) as f:
             return json.load(f)
 
     @property
     def mif(self):
         """MIF file.
-
         This property returns a string with the content of MIF file.
 
         Returns
         -------
         str
-
             MIF file content.
 
         Examples
         --------
         1. Getting MIF file.
-
         >>> import os
         >>> import micromagneticdata as md
         ...
@@ -197,40 +154,10 @@ class Drive:
         >>> drive = md.Drive(name='system_name', number=6, dirname=dirname)
         >>> drive.mif
         '# MIF 2...'
-
         """
-        with open(os.path.join(self.path, f'{self.name}.mif')) as f:
+        with open(os.path.join(self.path, f"{self.name}.mif")) as f:
             return f.read()
 
-    @property
-    def m0(self):
-        """Inital magnetisation.
-
-        This property returns a ``discretisedfield.Field`` object for the
-        initial magnetisation field.
-
-        Returns
-        -------
-        discretisedfield.Field
-
-            Initial magnetisation field.
-
-        Examples
-        --------
-        1. Getting initial magnetisation field.
-
-        >>> import os
-        >>> import micromagneticdata as md
-        ...
-        >>> dirname = dirname=os.path.join(os.path.dirname(__file__),
-        ...                                'tests', 'test_sample')
-        >>> drive = md.Drive(name='system_name', number=0, dirname=dirname)
-        >>> drive.m0
-        Field(...)
-
-        """
-        return df.Field.fromfile(os.path.join(self.path, 'm0.omf'))
-
     @property
     def table(self):
         """Table object.
@@ -259,96 +186,11 @@ class Drive:
                        E...
 
         """
-        return ut.Table.fromfile(os.path.join(self.path, f'{self.name}.odt'),
-                                 x=self.x)
-
-    @property
-    def n(self):
-        """Number of steps.
-
-        This property returns the number of rows in the drive table.
-
-        Returns
-        -------
-        int
-
-            Number of steps.
-
-        Examples
-        --------
-        1. Getting the number of steps.
-
-        >>> import os
-        >>> import micromagneticdata as md
-        ...
-        >>> dirname = dirname=os.path.join(os.path.dirname(__file__),
-        ...                                'tests', 'test_sample')
-        >>> drive = md.Drive(name='system_name', number=0, dirname=dirname)
-        >>> drive.n
-        25
-
-        """
-        return len(self.table.data.index)
+        return ut.Table.fromfile(os.path.join(self.path, f"{self.name}.odt"), x=self.x)
 
     @property
     def _step_files(self):
-        filenames = glob.iglob(os.path.join(self.path, f'{self.name}*.omf'))
-        for filename in sorted(filenames):
-            yield filename
-
-    def __getitem__(self, item):
-        """Magnetisation field of an individual step.
-
-        Returns
-        -------
-        int
-
-            Step number.
-
-        Examples
-        --------
-        1. Getting the field of a particular step.
-
-        >>> import os
-        >>> import micromagneticdata as md
-        ...
-        >>> dirname = dirname=os.path.join(os.path.dirname(__file__),
-        ...                                'tests', 'test_sample')
-        >>> drive = md.Drive(name='system_name', number=0, dirname=dirname)
-        >>> drive[5]
-        Field(...)
-
-        """
-        return df.Field.fromfile(filename=list(self._step_files)[item])
-
-    def __iter__(self):
-        """Iterator.
-
-        This iterator iterates through all magnetisation field in drive and
-        yields ``discretisedfield.Field`` objects.
-
-        Returns
-        -------
-        discretisedfield.Field
-
-            Magnetisation field.
-
-        Examples
-        --------
-        1. Iterating drive.
-
-        >>> import os
-        >>> import micromagneticdata as md
-        ...
-        >>> dirname = dirname=os.path.join(os.path.dirname(__file__),
-        ...                                'tests', 'test_sample')
-        >>> drive = md.Drive(name='system_name', number=0, dirname=dirname)
-        >>> list(drive)
-        [...]
-
-        """
-        for filename in self._step_files:
-            yield df.Field.fromfile(filename)
+        return sorted(glob.iglob(os.path.join(self.path, f"{self.name}*.omf")))
 
     def ovf2vtk(self, dirname=None):
         """OVF to VTK conversion.
@@ -372,11 +214,10 @@ class Drive:
         if dirname is None:
             dirname = self.path
         for i, filename in enumerate(self._step_files):
-            vtkfilename = 'drive-{}-{:07d}.vtk'.format(self.number, i)
-            df.Field.fromfile(filename).write(os.path.join(dirname,
-                                                           vtkfilename))
+            vtkfilename = "drive-{}-{:07d}.vtk".format(self.number, i)
+            df.Field.fromfile(filename).write(os.path.join(dirname, vtkfilename))
 
-    def slider(self, description='step', **kwargs):
+    def slider(self, description="step", **kwargs):
         """Widget for selecting individual steps.
 
         This method is based on ``ipywidgets.IntSlider``, so any keyword
@@ -408,9 +249,13 @@ class Drive:
         IntSlider(...)
 
         """
-        return ipywidgets.IntSlider(value=0,
-                                    min=0,
-                                    max=self.n-1,
-                                    step=1,
-                                    description=description,
-                                    **kwargs)
+        return ipywidgets.IntSlider(
+            value=0, min=0, max=self.n - 1, step=1, description=description, **kwargs
+        )
+
+    def __lshift__(self, other):
+        if isinstance(other, self.__class__):
+            return md.CombinedDrive(self, other)
+        elif isinstance(other, md.CombinedDrive):
+            return md.CombinedDrive(self, *other.drives)
+        raise TypeError(f"Invalid type {other=}.")
