@@ -1,14 +1,16 @@
 import os
-import pytest
+
 import ipywidgets
 import pandas as pd
+import pytest
+
 import micromagneticdata as md
 
 
 class TestData:
     def setup(self):
-        self.dirname = os.path.join(os.path.dirname(__file__), 'test_sample')
-        self.name = 'system_name'
+        self.dirname = os.path.join(os.path.dirname(__file__), "test_sample")
+        self.name = "system_name"
         self.data = md.Data(name=self.name, dirname=self.dirname)
 
     def test_init(self):
@@ -16,11 +18,11 @@ class TestData:
 
         # Exception
         with pytest.raises(IOError):
-            data = md.Data(name='wrong', dirname=self.dirname)
+            md.Data(name="wrong", dirname=self.dirname)
 
     def test_repr(self):
         assert isinstance(repr(self.data), str)
-        assert 'Data' in repr(self.data)
+        assert "Data" in repr(self.data)
 
     def test_info(self):
         assert isinstance(self.data.info, pd.DataFrame)
@@ -30,7 +32,7 @@ class TestData:
         assert self.data.n == 7
 
     def test_getitem(self):
-        for i in [-2, -1, 0, 1, 2, 3, 4, 5, 6, 7]:
+        for i in [-2, -1, 0, 1, 2, 3, 4, 5, 6]:
             assert isinstance(self.data[i], md.Drive)
 
     def test_iter(self):
